=========
Changelog
=========

1.0.1 - 2012-07-19
==================

 * Added --hash-dir argument to allow changing hash file dir during runtime
 * Added ``compress`` INI file option to avoid compressing destination file
 * Added --example-cfg argument to create an example_shrink.cfg file in
   current folder

1.0.0 - 2012-07-11
==================

 * Added --version argument
 * Added SHA1 hashing support (``hash = true`` in any file section)
 * Added --hash-all argument to generae SHA1 hash using all files contents
